@@ -83,6 +83,10 @@ module Excon
 
       if ENV.has_key?('EXCON_DEBUG') || ENV.has_key?('EXCON_STANDARD_INSTRUMENTOR')
         @data[:instrumentor] = Excon::StandardInstrumentor
+
+        if ENV.has_key?('EXCON_DEBUG')
+          @data[:debug_request] = @data[:debug_reponse] = true
+        end
       end
 
       # Use Basic Auth if url contains a login
@@ -269,7 +273,7 @@ module Excon
 
         if datum[:persistent]
           if key = datum[:response][:headers].keys.detect {|k| k.casecmp('Connection') == 0 }
-            if split_header_value(datum[:response][:headers][key]).any? {|t| t.casecmp('close') }
+            if split_header_value(datum[:response][:headers][key]).any? {|t| t.casecmp('close') == 0 }
               reset
             end
           end
@@ -305,7 +309,7 @@ module Excon
 
       if @data[:persistent]
         if key = responses.last[:headers].keys.detect {|k| k.casecmp('Connection') == 0 }
-          if split_header_value(responses.last[:headers][key]).any? {|t| t.casecmp('close') }
+          if split_header_value(responses.last[:headers][key]).any? {|t| t.casecmp('close') == 0 }
             reset
           end
         end
